==> muitv-0.4.0.tgz: package/src/components/demo/SearchDemo.js <==
import React, { Component } from "react";

import Search from "components/layouts/Search";
import IconButton from "@material-ui/core/IconButton";
import SearchIcon from "@material-ui/icons/Search";

import Input from '@material-ui/core/Input';
import InputLabel from '@material-ui/core/InputLabel';
import InputAdornment from '@material-ui/core/InputAdornment';
import FormHelperText from '@material-ui/core/FormHelperText';
import FormControl from '@material-ui/core/FormControl';
import TextField from '@material-ui/core/TextField';

import { withStyles } from "@material-ui/core/styles";
import classNames from "classnames";

const styles = theme => ({
  button1: {
    margin: theme.spacing.unit,
    height: "2em",
    width: "2em"
  },
  icon1: {
    width: "1em",
    height: "1em"
  },
  button2: {
    margin: theme.spacing.unit * 1.3,
    height: "2.6em",
    width: "2.6em"
  },
  icon2: {
    width: "1.3em",
    height: "1.3em"
  },
  button3: {
    margin: theme.spacing.unit * 2,
    height: "4em",
    width: "4em"
  },
  icon3: {
    width: "2em",
    height: "2em"
  }
});

class SearchDemo extends Component {
  render() {
    const { classes } = this.props;
    const sprops = {};
    const ih = window.innerHeight;

    const buttonClass =
      ih > 1000
        ? classes.button3
        : ih > 700 ? classes.button2 : classes.button1;
    const iconClass =
      ih > 1000 ? classes.icon3 : ih > 700 ? classes.icon2 : classes.icon1;

    sprops.button = (
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
        <SearchIcon className={iconClass} />
      </IconButton>
    );

    sprops.input = (<TextField
          className={classNames(classes.margin, classes.textField)}
          placeholder="Search for your music here..."
          InputProps={{
            fullWidth: true,
            startAdornment: <InputAdornment position="end"><SearchIcon/></InputAdornment>,
          }}
        />);

    sprops.results = (<span>results...</span>);

    return <Search {...sprops} />;
  }
}

export default withStyles(styles)(SearchDemo);

==> muitv-0.6.1.tgz: package/src/components/demo/SearchDemo.js <==
import React, { Component } from "react";

import Search from "components/layouts/Search";
import IconButton from "@material-ui/core/IconButton";
import SearchIcon from "@material-ui/icons/Search";

import Input from '@material-ui/core/Input';
import InputLabel from '@material-ui/core/InputLabel';
import InputAdornment from '@material-ui/core/InputAdornment';
import FormHelperText from '@material-ui/core/FormHelperText';
import FormControl from '@material-ui/core/FormControl';
import TextField from '@material-ui/core/TextField';

import { withStyles } from "@material-ui/core/styles";
import classNames from "classnames";

const styles = theme => ({
  button1: {
    margin: theme.spacing(1),
    height: "2em",
    width: "2em"
  },
  icon1: {
    width: "1em",
    height: "1em"
  },
  button2: {
    margin: theme.spacing(1.3),
    height: "2.6em",
    width: "2.6em"
  },
  icon2: {
    width: "1.3em",
    height: "1.3em"
  },
  button3: {
    margin: theme.spacing(2),
    height: "4em",
    width: "4em"
  },
  icon3: {
    width: "2em",
    height: "2em"
  }
});

class SearchDemo extends Component {
  render() {
    const { classes } = this.props;
    const sprops = {};
    const ih = window.innerHeight;

    const buttonClass =
      ih > 1000
        ? classes.button3
        : ih > 700 ? classes.button2 : classes.button1;
    const iconClass =
      ih > 1000 ? classes.icon3 : ih > 700 ? classes.icon2 : classes.icon1;

    sprops.button = (
      <IconButton
        variant="fab"
        color="secondary"
        className={buttonClass}
        aria-label="Delete"
      >
        <SearchIcon className={iconClass} />
      </IconButton>
    );

    sprops.input = (<TextField
          className={classNames(classes.margin, classes.textField)}
          placeholder="Search for your music here..."
          InputProps={{
            fullWidth: true,
            startAdornment: <InputAdornment position="end"><SearchIcon/></InputAdornment>,
          }}
        />);

    sprops.results = (<span>results...</span>);

    return <Search {...sprops} />;
  }
}

export default withStyles(styles)(SearchDemo);
